@@ -3,8 +3,9 @@ use v5.10;
 use Dancer ':syntax';
 use Dancer::Plugin;
 use Scalar::Util 'blessed';
+use Time::HiRes 'time';
 
-our $VERSION = '1.08';
+our $VERSION = '1.09';
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
@@ -79,6 +80,7 @@ register PLUGIN_NAME ,=> sub {
         my @method_args = map $_->value, @{$request->args};
 
         debug("[handle_xmlrpc_call($method_name)] ", \@method_args);
+        my $start_request = time();
         my Dancer::RPCPlugin::CallbackResult $continue = eval {
             local $Dancer::RPCPlugin::ROUTE_INFO = {
                 plugin        => PLUGIN_NAME,
@@ -145,6 +147,10 @@ register PLUGIN_NAME ,=> sub {
                 $response = flatten_data($response);
             }
         }
+        info( sprintf(
+            "[RPC::XMLRPC] request for %s took %.4fs",
+            $method_name, time() - $start_request
+        ));
         return xmlrpc_response($response);
     };
 
